smart_grow_logs_plugin library

Classes

InitOptions
Configuration options for initializing Smart Grow Logs
LogOptions
Options for sending a log entry
LogResponse
Response from Smart Grow Logs server after sending a log
SmartGrowLogs
SmartGrowLogs - Secure logging SDK for Flutter
SmartGrowLogsAPI
Internal API class for communicating with native plugins via MethodChannel

Enums

LogLevel
Log levels supported by Smart Grow Logs