InitOptions class
Configuration options for initializing Smart Grow Logs
Constructors
Properties
- androidAnrTimeoutMs → int
-
Android ANR watchdog timeout in milliseconds.
final
- androidAnrWatchdogEnabled → bool
-
Enable Android ANR watchdog capture.
final
- apiKey → String
-
API Key for authentication (required)
final
- autoCaptureEnabled → bool
-
Automatically capture unhandled framework/runtime errors.
final
- baseUrl → String
-
Base URL of the Smart Grow Logs server (required)
final
- debug → bool
-
Enable debug logging (optional, default: false)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited